pub struct Element {
pub id: Option<u64>,
pub type_: Option<ElementType>,
pub type_specific: Option<TypeSpecificElement>,
pub description: Option<String>,
pub can_stop: Option<bool>,
pub can_bypass: Option<bool>,
/* private fields */
}Fields
id: Option<u64>Unique ID for this element. The scope of this id is only within the SignalProcessing
protocol lifespan, i.e. until the channel associated with the protocol is closed.
Required.
type_: Option<ElementType>Processing element type.
Required.
type_specific: Option<TypeSpecificElement>Type-specific parameters for the processing element.
Required for ElementTypes DAI_INTERCONNECT, DYNAMICS, EQUALIZER, GAIN, VENDOR_SPECIFIC.
Invalid if specified for elements of type AUTOMATIC_GAIN_CONTROL, AUTOMATIC_GAIN_LIMITER,
CONNECTION_POINT, DELAY, MUTE, RING_BUFFER or SAMPLE_RATE_CONVERSION.
description: Option<String>If included, a textual description of the processing element.
Optional. If present, must not be empty.
can_stop: Option<bool>If true, the processing element can be stopped via SetElementState.
If not included or false, the processing element is always started.
Optional.
can_bypass: Option<bool>If true, the processing element can be bypassed via SetElementState.
If not included or false, the processing element cannot be bypassed.
By definition, elements of type DAI_INTERCONNECT or RING_BUFFER cannot be bypassed and
must never set this field to true.
Optional.